@@ -175,7 +175,9 @@ class AreaService(BaseRdbmsService):
             areas = [
                 row.get_object({
                     'area_id': cast.string_to_uuid,
-                    'parent_area_id': cast.string_to_uuid })
+                    'locale': Locale,
+                    'parent_area_id': cast.string_to_uuid
+                })
                 for row in cursor.fetch_all()]
 
             for area in areas:
@@ -601,10 +603,9 @@ class AreaService(BaseRdbmsService):
             * ``parent_area_id`` (optional): identification of the parent geographic
               area or ``None`` if none defined.
         """
-        location = self.find_location_with_ip_address(app_id, ip_address, connection=connection)
+        location = self.find_location_with_ip_address(ip_address, connection=connection)
 
         return [] if location is None else self.get_areas_by_location(
-            app_id,
             location,
             connection=connection,
             lowest_area_level=lowest_area_level,
@@ -728,8 +729,10 @@ class AreaService(BaseRdbmsService):
                 row.get_object({
                     'area_id': cast.string_to_uuid,
                     'parent_area_id': cast.string_to_uuid,
-                    'locale': cast.string_to_locale})
-                for row in cursor.fetch_all()]
+                    'locale': cast.string_to_locale
+                })
+                for row in cursor.fetch_all()
+            ]
 
             for area in areas:
                 area.label = Label(area.content, area.locale)
@@ -752,7 +755,7 @@ class AreaService(BaseRdbmsService):
             connection=None,
             lowest_area_level=area.AREA_LEVEL_WARD,
             highest_area_level=area.AREA_LEVEL_COUNTRY,
-            locale=DEFAULT_LOCALE,
+            locale=None,
             minimal_area_surface=None):
         """
         Return the geographic areas that encompass the specified location.
@@ -840,7 +843,7 @@ class AreaService(BaseRdbmsService):
                 {
                     'highest_area_level': highest_area_level,
                     'latitude': location.latitude,
-                    'locale': locale,
+                    'locale': locale or DEFAULT_LOCALE,
                     'lowest_area_level': lowest_area_level,
                     'longitude': location.longitude,
                     'minimal_area_surface': minimal_area_surface or 0
@@ -850,7 +853,8 @@ class AreaService(BaseRdbmsService):
                 row.get_object({
                     'area_id': cast.string_to_uuid,
                     'locale': Locale,
-                    'parent_area_id': cast.string_to_uuid })
+                    'parent_area_id': cast.string_to_uuid
+                })
                 for row in cursor.fetch_all()
             ]
 
